import os
import pytest


def test_sky_basic():
    from lef_parser import parse_files

    lef = parse_files(
        [
            os.path.join(pytest.test_root, "files", "sky.tlef"),
            os.path.join(pytest.test_root, "files", "sky.lef"),
        ]
    )
    assert list(lef.layers.keys()) == [
        "nwell",
        "pwell",
        "li1",
        "mcon",
        "met1",
        "via",
        "met2",
        "via2",
        "met3",
        "via3",
        "met4",
        "via4",
        "met5",
    ], "Layers not extracted successfully"
    assert list(lef.macros.keys()) == [
        "sky130_fd_sc_hd__a2bb2o_1",
        "sky130_fd_sc_hd__a2bb2o_2",
        "sky130_fd_sc_hd__a2bb2o_4",
        "sky130_fd_sc_hd__a2bb2oi_1",
        "sky130_fd_sc_hd__a2bb2oi_2",
        "sky130_fd_sc_hd__a2bb2oi_4",
        "sky130_fd_sc_hd__a21bo_1",
        "sky130_fd_sc_hd__a21bo_2",
        "sky130_fd_sc_hd__a21bo_4",
        "sky130_fd_sc_hd__a21boi_0",
        "sky130_fd_sc_hd__a21boi_1",
        "sky130_fd_sc_hd__a21boi_2",
        "sky130_fd_sc_hd__a21boi_4",
        "sky130_fd_sc_hd__a21o_1",
        "sky130_fd_sc_hd__a21o_2",
        "sky130_fd_sc_hd__a21o_4",
        "sky130_fd_sc_hd__a21oi_1",
        "sky130_fd_sc_hd__a21oi_2",
        "sky130_fd_sc_hd__a21oi_4",
        "sky130_fd_sc_hd__a22o_1",
        "sky130_fd_sc_hd__a22o_2",
        "sky130_fd_sc_hd__a22o_4",
        "sky130_fd_sc_hd__a22oi_1",
        "sky130_fd_sc_hd__a22oi_2",
        "sky130_fd_sc_hd__a22oi_4",
        "sky130_fd_sc_hd__a31o_1",
        "sky130_fd_sc_hd__a31o_2",
        "sky130_fd_sc_hd__a31o_4",
        "sky130_fd_sc_hd__a31oi_1",
        "sky130_fd_sc_hd__a31oi_2",
        "sky130_fd_sc_hd__a31oi_4",
        "sky130_fd_sc_hd__a32o_1",
        "sky130_fd_sc_hd__a32o_2",
        "sky130_fd_sc_hd__a32o_4",
        "sky130_fd_sc_hd__a32oi_1",
        "sky130_fd_sc_hd__a32oi_2",
        "sky130_fd_sc_hd__a32oi_4",
        "sky130_fd_sc_hd__a41o_1",
        "sky130_fd_sc_hd__a41o_2",
        "sky130_fd_sc_hd__a41o_4",
        "sky130_fd_sc_hd__a41oi_1",
        "sky130_fd_sc_hd__a41oi_2",
        "sky130_fd_sc_hd__a41oi_4",
        "sky130_fd_sc_hd__a211o_1",
        "sky130_fd_sc_hd__a211o_2",
        "sky130_fd_sc_hd__a211o_4",
        "sky130_fd_sc_hd__a211oi_1",
        "sky130_fd_sc_hd__a211oi_2",
        "sky130_fd_sc_hd__a211oi_4",
        "sky130_fd_sc_hd__a221o_1",
        "sky130_fd_sc_hd__a221o_2",
        "sky130_fd_sc_hd__a221o_4",
        "sky130_fd_sc_hd__a221oi_1",
        "sky130_fd_sc_hd__a221oi_2",
        "sky130_fd_sc_hd__a221oi_4",
        "sky130_fd_sc_hd__a222oi_1",
        "sky130_fd_sc_hd__a311o_1",
        "sky130_fd_sc_hd__a311o_2",
        "sky130_fd_sc_hd__a311o_4",
        "sky130_fd_sc_hd__a311oi_1",
        "sky130_fd_sc_hd__a311oi_2",
        "sky130_fd_sc_hd__a311oi_4",
        "sky130_fd_sc_hd__a2111o_1",
        "sky130_fd_sc_hd__a2111o_2",
        "sky130_fd_sc_hd__a2111o_4",
        "sky130_fd_sc_hd__a2111oi_0",
        "sky130_fd_sc_hd__a2111oi_1",
        "sky130_fd_sc_hd__a2111oi_2",
        "sky130_fd_sc_hd__a2111oi_4",
        "sky130_fd_sc_hd__and2_0",
        "sky130_fd_sc_hd__and2_1",
        "sky130_fd_sc_hd__and2_2",
        "sky130_fd_sc_hd__and2_4",
        "sky130_fd_sc_hd__and2b_1",
        "sky130_fd_sc_hd__and2b_2",
        "sky130_fd_sc_hd__and2b_4",
        "sky130_fd_sc_hd__and3_1",
        "sky130_fd_sc_hd__and3_2",
        "sky130_fd_sc_hd__and3_4",
        "sky130_fd_sc_hd__and3b_1",
        "sky130_fd_sc_hd__and3b_2",
        "sky130_fd_sc_hd__and3b_4",
        "sky130_fd_sc_hd__and4_1",
        "sky130_fd_sc_hd__and4_2",
        "sky130_fd_sc_hd__and4_4",
        "sky130_fd_sc_hd__and4b_1",
        "sky130_fd_sc_hd__and4b_2",
        "sky130_fd_sc_hd__and4b_4",
        "sky130_fd_sc_hd__and4bb_1",
        "sky130_fd_sc_hd__and4bb_2",
        "sky130_fd_sc_hd__and4bb_4",
        "sky130_fd_sc_hd__buf_1",
        "sky130_fd_sc_hd__buf_2",
        "sky130_fd_sc_hd__buf_4",
        "sky130_fd_sc_hd__buf_6",
        "sky130_fd_sc_hd__buf_8",
        "sky130_fd_sc_hd__buf_12",
        "sky130_fd_sc_hd__buf_16",
        "sky130_fd_sc_hd__bufbuf_8",
        "sky130_fd_sc_hd__bufbuf_16",
        "sky130_fd_sc_hd__bufinv_8",
        "sky130_fd_sc_hd__bufinv_16",
        "sky130_fd_sc_hd__clkbuf_1",
        "sky130_fd_sc_hd__clkbuf_2",
        "sky130_fd_sc_hd__clkbuf_4",
        "sky130_fd_sc_hd__clkbuf_8",
        "sky130_fd_sc_hd__clkbuf_16",
        "sky130_fd_sc_hd__clkdlybuf4s15_1",
        "sky130_fd_sc_hd__clkdlybuf4s15_2",
        "sky130_fd_sc_hd__clkdlybuf4s18_1",
        "sky130_fd_sc_hd__clkdlybuf4s18_2",
        "sky130_fd_sc_hd__clkdlybuf4s25_1",
        "sky130_fd_sc_hd__clkdlybuf4s25_2",
        "sky130_fd_sc_hd__clkdlybuf4s50_1",
        "sky130_fd_sc_hd__clkdlybuf4s50_2",
        "sky130_fd_sc_hd__clkinv_1",
        "sky130_fd_sc_hd__clkinv_2",
        "sky130_fd_sc_hd__clkinv_4",
        "sky130_fd_sc_hd__clkinv_8",
        "sky130_fd_sc_hd__clkinv_16",
        "sky130_fd_sc_hd__clkinvlp_2",
        "sky130_fd_sc_hd__clkinvlp_4",
        "sky130_fd_sc_hd__conb_1",
        "sky130_fd_sc_hd__decap_3",
        "sky130_fd_sc_hd__decap_4",
        "sky130_fd_sc_hd__decap_6",
        "sky130_fd_sc_hd__decap_8",
        "sky130_fd_sc_hd__decap_12",
        "sky130_fd_sc_hd__dfbbn_1",
        "sky130_fd_sc_hd__dfbbn_2",
        "sky130_fd_sc_hd__dfbbp_1",
        "sky130_fd_sc_hd__dfrbp_1",
        "sky130_fd_sc_hd__dfrbp_2",
        "sky130_fd_sc_hd__dfrtn_1",
        "sky130_fd_sc_hd__dfrtp_1",
        "sky130_fd_sc_hd__dfrtp_2",
        "sky130_fd_sc_hd__dfrtp_4",
        "sky130_fd_sc_hd__dfsbp_1",
        "sky130_fd_sc_hd__dfsbp_2",
        "sky130_fd_sc_hd__dfstp_1",
        "sky130_fd_sc_hd__dfstp_2",
        "sky130_fd_sc_hd__dfstp_4",
        "sky130_fd_sc_hd__dfxbp_1",
        "sky130_fd_sc_hd__dfxbp_2",
        "sky130_fd_sc_hd__dfxtp_1",
        "sky130_fd_sc_hd__dfxtp_2",
        "sky130_fd_sc_hd__dfxtp_4",
        "sky130_fd_sc_hd__diode_2",
        "sky130_fd_sc_hd__dlclkp_1",
        "sky130_fd_sc_hd__dlclkp_2",
        "sky130_fd_sc_hd__dlclkp_4",
        "sky130_fd_sc_hd__dlrbn_1",
        "sky130_fd_sc_hd__dlrbn_2",
        "sky130_fd_sc_hd__dlrbp_1",
        "sky130_fd_sc_hd__dlrbp_2",
        "sky130_fd_sc_hd__dlrtn_1",
        "sky130_fd_sc_hd__dlrtn_2",
        "sky130_fd_sc_hd__dlrtn_4",
        "sky130_fd_sc_hd__dlrtp_1",
        "sky130_fd_sc_hd__dlrtp_2",
        "sky130_fd_sc_hd__dlrtp_4",
        "sky130_fd_sc_hd__dlxbn_1",
        "sky130_fd_sc_hd__dlxbn_2",
        "sky130_fd_sc_hd__dlxbp_1",
        "sky130_fd_sc_hd__dlxtn_1",
        "sky130_fd_sc_hd__dlxtn_2",
        "sky130_fd_sc_hd__dlxtn_4",
        "sky130_fd_sc_hd__dlxtp_1",
        "sky130_fd_sc_hd__dlygate4sd1_1",
        "sky130_fd_sc_hd__dlygate4sd2_1",
        "sky130_fd_sc_hd__dlygate4sd3_1",
        "sky130_fd_sc_hd__dlymetal6s2s_1",
        "sky130_fd_sc_hd__dlymetal6s4s_1",
        "sky130_fd_sc_hd__dlymetal6s6s_1",
        "sky130_fd_sc_hd__ebufn_1",
        "sky130_fd_sc_hd__ebufn_2",
        "sky130_fd_sc_hd__ebufn_4",
        "sky130_fd_sc_hd__ebufn_8",
        "sky130_fd_sc_hd__edfxbp_1",
        "sky130_fd_sc_hd__edfxtp_1",
        "sky130_fd_sc_hd__einvn_0",
        "sky130_fd_sc_hd__einvn_1",
        "sky130_fd_sc_hd__einvn_2",
        "sky130_fd_sc_hd__einvn_4",
        "sky130_fd_sc_hd__einvn_8",
        "sky130_fd_sc_hd__einvp_1",
        "sky130_fd_sc_hd__einvp_2",
        "sky130_fd_sc_hd__einvp_4",
        "sky130_fd_sc_hd__einvp_8",
        "sky130_fd_sc_hd__fa_1",
        "sky130_fd_sc_hd__fa_2",
        "sky130_fd_sc_hd__fa_4",
        "sky130_fd_sc_hd__fah_1",
        "sky130_fd_sc_hd__fahcin_1",
        "sky130_fd_sc_hd__fahcon_1",
        "sky130_fd_sc_hd__fill_1",
        "sky130_fd_sc_hd__fill_2",
        "sky130_fd_sc_hd__fill_4",
        "sky130_fd_sc_hd__fill_8",
        "sky130_fd_sc_hd__ha_1",
        "sky130_fd_sc_hd__ha_2",
        "sky130_fd_sc_hd__ha_4",
        "sky130_fd_sc_hd__inv_1",
        "sky130_fd_sc_hd__inv_2",
        "sky130_fd_sc_hd__inv_4",
        "sky130_fd_sc_hd__inv_6",
        "sky130_fd_sc_hd__inv_8",
        "sky130_fd_sc_hd__inv_12",
        "sky130_fd_sc_hd__inv_16",
        "sky130_fd_sc_hd__lpflow_bleeder_1",
        "sky130_fd_sc_hd__lpflow_clkbufkapwr_1",
        "sky130_fd_sc_hd__lpflow_clkbufkapwr_2",
        "sky130_fd_sc_hd__lpflow_clkbufkapwr_4",
        "sky130_fd_sc_hd__lpflow_clkbufkapwr_8",
        "sky130_fd_sc_hd__lpflow_clkbufkapwr_16",
        "sky130_fd_sc_hd__lpflow_clkinvkapwr_1",
        "sky130_fd_sc_hd__lpflow_clkinvkapwr_2",
        "sky130_fd_sc_hd__lpflow_clkinvkapwr_4",
        "sky130_fd_sc_hd__lpflow_clkinvkapwr_8",
        "sky130_fd_sc_hd__lpflow_clkinvkapwr_16",
        "sky130_fd_sc_hd__lpflow_decapkapwr_3",
        "sky130_fd_sc_hd__lpflow_decapkapwr_4",
        "sky130_fd_sc_hd__lpflow_decapkapwr_6",
        "sky130_fd_sc_hd__lpflow_decapkapwr_8",
        "sky130_fd_sc_hd__lpflow_decapkapwr_12",
        "sky130_fd_sc_hd__lpflow_inputiso0n_1",
        "sky130_fd_sc_hd__lpflow_inputiso0p_1",
        "sky130_fd_sc_hd__lpflow_inputiso1n_1",
        "sky130_fd_sc_hd__lpflow_inputiso1p_1",
        "sky130_fd_sc_hd__lpflow_inputisolatch_1",
        "sky130_fd_sc_hd__lpflow_isobufsrc_1",
        "sky130_fd_sc_hd__lpflow_isobufsrc_2",
        "sky130_fd_sc_hd__lpflow_isobufsrc_4",
        "sky130_fd_sc_hd__lpflow_isobufsrc_8",
        "sky130_fd_sc_hd__lpflow_isobufsrc_16",
        "sky130_fd_sc_hd__lpflow_isobufsrckapwr_16",
        "sky130_fd_sc_hd__lpflow_lsbuf_lh_hl_isowell_tap_1",
        "sky130_fd_sc_hd__lpflow_lsbuf_lh_hl_isowell_tap_2",
        "sky130_fd_sc_hd__lpflow_lsbuf_lh_hl_isowell_tap_4",
        "sky130_fd_sc_hd__lpflow_lsbuf_lh_isowell_4",
        "sky130_fd_sc_hd__lpflow_lsbuf_lh_isowell_tap_1",
        "sky130_fd_sc_hd__lpflow_lsbuf_lh_isowell_tap_2",
        "sky130_fd_sc_hd__lpflow_lsbuf_lh_isowell_tap_4",
        "sky130_fd_sc_hd__macro_sparecell",
        "sky130_fd_sc_hd__maj3_1",
        "sky130_fd_sc_hd__maj3_2",
        "sky130_fd_sc_hd__maj3_4",
        "sky130_fd_sc_hd__mux2_1",
        "sky130_fd_sc_hd__mux2_2",
        "sky130_fd_sc_hd__mux2_4",
        "sky130_fd_sc_hd__mux2_8",
        "sky130_fd_sc_hd__mux2i_1",
        "sky130_fd_sc_hd__mux2i_2",
        "sky130_fd_sc_hd__mux2i_4",
        "sky130_fd_sc_hd__mux4_1",
        "sky130_fd_sc_hd__mux4_2",
        "sky130_fd_sc_hd__mux4_4",
        "sky130_fd_sc_hd__nand2_1",
        "sky130_fd_sc_hd__nand2_2",
        "sky130_fd_sc_hd__nand2_4",
        "sky130_fd_sc_hd__nand2_8",
        "sky130_fd_sc_hd__nand2b_1",
        "sky130_fd_sc_hd__nand2b_2",
        "sky130_fd_sc_hd__nand2b_4",
        "sky130_fd_sc_hd__nand3_1",
        "sky130_fd_sc_hd__nand3_2",
        "sky130_fd_sc_hd__nand3_4",
        "sky130_fd_sc_hd__nand3b_1",
        "sky130_fd_sc_hd__nand3b_2",
        "sky130_fd_sc_hd__nand3b_4",
        "sky130_fd_sc_hd__nand4_1",
        "sky130_fd_sc_hd__nand4_2",
        "sky130_fd_sc_hd__nand4_4",
        "sky130_fd_sc_hd__nand4b_1",
        "sky130_fd_sc_hd__nand4b_2",
        "sky130_fd_sc_hd__nand4b_4",
        "sky130_fd_sc_hd__nand4bb_1",
        "sky130_fd_sc_hd__nand4bb_2",
        "sky130_fd_sc_hd__nand4bb_4",
        "sky130_fd_sc_hd__nor2_1",
        "sky130_fd_sc_hd__nor2_2",
        "sky130_fd_sc_hd__nor2_4",
        "sky130_fd_sc_hd__nor2_8",
        "sky130_fd_sc_hd__nor2b_1",
        "sky130_fd_sc_hd__nor2b_2",
        "sky130_fd_sc_hd__nor2b_4",
        "sky130_fd_sc_hd__nor3_1",
        "sky130_fd_sc_hd__nor3_2",
        "sky130_fd_sc_hd__nor3_4",
        "sky130_fd_sc_hd__nor3b_1",
        "sky130_fd_sc_hd__nor3b_2",
        "sky130_fd_sc_hd__nor3b_4",
        "sky130_fd_sc_hd__nor4_1",
        "sky130_fd_sc_hd__nor4_2",
        "sky130_fd_sc_hd__nor4_4",
        "sky130_fd_sc_hd__nor4b_1",
        "sky130_fd_sc_hd__nor4b_2",
        "sky130_fd_sc_hd__nor4b_4",
        "sky130_fd_sc_hd__nor4bb_1",
        "sky130_fd_sc_hd__nor4bb_2",
        "sky130_fd_sc_hd__nor4bb_4",
        "sky130_fd_sc_hd__o2bb2a_1",
        "sky130_fd_sc_hd__o2bb2a_2",
        "sky130_fd_sc_hd__o2bb2a_4",
        "sky130_fd_sc_hd__o2bb2ai_1",
        "sky130_fd_sc_hd__o2bb2ai_2",
        "sky130_fd_sc_hd__o2bb2ai_4",
        "sky130_fd_sc_hd__o21a_1",
        "sky130_fd_sc_hd__o21a_2",
        "sky130_fd_sc_hd__o21a_4",
        "sky130_fd_sc_hd__o21ai_0",
        "sky130_fd_sc_hd__o21ai_1",
        "sky130_fd_sc_hd__o21ai_2",
        "sky130_fd_sc_hd__o21ai_4",
        "sky130_fd_sc_hd__o21ba_1",
        "sky130_fd_sc_hd__o21ba_2",
        "sky130_fd_sc_hd__o21ba_4",
        "sky130_fd_sc_hd__o21bai_1",
        "sky130_fd_sc_hd__o21bai_2",
        "sky130_fd_sc_hd__o21bai_4",
        "sky130_fd_sc_hd__o22a_1",
        "sky130_fd_sc_hd__o22a_2",
        "sky130_fd_sc_hd__o22a_4",
        "sky130_fd_sc_hd__o22ai_1",
        "sky130_fd_sc_hd__o22ai_2",
        "sky130_fd_sc_hd__o22ai_4",
        "sky130_fd_sc_hd__o31a_1",
        "sky130_fd_sc_hd__o31a_2",
        "sky130_fd_sc_hd__o31a_4",
        "sky130_fd_sc_hd__o31ai_1",
        "sky130_fd_sc_hd__o31ai_2",
        "sky130_fd_sc_hd__o31ai_4",
        "sky130_fd_sc_hd__o32a_1",
        "sky130_fd_sc_hd__o32a_2",
        "sky130_fd_sc_hd__o32a_4",
        "sky130_fd_sc_hd__o32ai_1",
        "sky130_fd_sc_hd__o32ai_2",
        "sky130_fd_sc_hd__o32ai_4",
        "sky130_fd_sc_hd__o41a_1",
        "sky130_fd_sc_hd__o41a_2",
        "sky130_fd_sc_hd__o41a_4",
        "sky130_fd_sc_hd__o41ai_1",
        "sky130_fd_sc_hd__o41ai_2",
        "sky130_fd_sc_hd__o41ai_4",
        "sky130_fd_sc_hd__o211a_1",
        "sky130_fd_sc_hd__o211a_2",
        "sky130_fd_sc_hd__o211a_4",
        "sky130_fd_sc_hd__o211ai_1",
        "sky130_fd_sc_hd__o211ai_2",
        "sky130_fd_sc_hd__o211ai_4",
        "sky130_fd_sc_hd__o221a_1",
        "sky130_fd_sc_hd__o221a_2",
        "sky130_fd_sc_hd__o221a_4",
        "sky130_fd_sc_hd__o221ai_1",
        "sky130_fd_sc_hd__o221ai_2",
        "sky130_fd_sc_hd__o221ai_4",
        "sky130_fd_sc_hd__o311a_1",
        "sky130_fd_sc_hd__o311a_2",
        "sky130_fd_sc_hd__o311a_4",
        "sky130_fd_sc_hd__o311ai_0",
        "sky130_fd_sc_hd__o311ai_1",
        "sky130_fd_sc_hd__o311ai_2",
        "sky130_fd_sc_hd__o311ai_4",
        "sky130_fd_sc_hd__o2111a_1",
        "sky130_fd_sc_hd__o2111a_2",
        "sky130_fd_sc_hd__o2111a_4",
        "sky130_fd_sc_hd__o2111ai_1",
        "sky130_fd_sc_hd__o2111ai_2",
        "sky130_fd_sc_hd__o2111ai_4",
        "sky130_fd_sc_hd__or2_0",
        "sky130_fd_sc_hd__or2_1",
        "sky130_fd_sc_hd__or2_2",
        "sky130_fd_sc_hd__or2_4",
        "sky130_fd_sc_hd__or2b_1",
        "sky130_fd_sc_hd__or2b_2",
        "sky130_fd_sc_hd__or2b_4",
        "sky130_fd_sc_hd__or3_1",
        "sky130_fd_sc_hd__or3_2",
        "sky130_fd_sc_hd__or3_4",
        "sky130_fd_sc_hd__or3b_1",
        "sky130_fd_sc_hd__or3b_2",
        "sky130_fd_sc_hd__or3b_4",
        "sky130_fd_sc_hd__or4_1",
        "sky130_fd_sc_hd__or4_2",
        "sky130_fd_sc_hd__or4_4",
        "sky130_fd_sc_hd__or4b_1",
        "sky130_fd_sc_hd__or4b_2",
        "sky130_fd_sc_hd__or4b_4",
        "sky130_fd_sc_hd__or4bb_1",
        "sky130_fd_sc_hd__or4bb_2",
        "sky130_fd_sc_hd__or4bb_4",
        "sky130_fd_sc_hd__probe_p_8",
        "sky130_fd_sc_hd__probec_p_8",
        "sky130_fd_sc_hd__sdfbbn_1",
        "sky130_fd_sc_hd__sdfbbn_2",
        "sky130_fd_sc_hd__sdfbbp_1",
        "sky130_fd_sc_hd__sdfrbp_1",
        "sky130_fd_sc_hd__sdfrbp_2",
        "sky130_fd_sc_hd__sdfrtn_1",
        "sky130_fd_sc_hd__sdfrtp_1",
        "sky130_fd_sc_hd__sdfrtp_2",
        "sky130_fd_sc_hd__sdfrtp_4",
        "sky130_fd_sc_hd__sdfsbp_1",
        "sky130_fd_sc_hd__sdfsbp_2",
        "sky130_fd_sc_hd__sdfstp_1",
        "sky130_fd_sc_hd__sdfstp_2",
        "sky130_fd_sc_hd__sdfstp_4",
        "sky130_fd_sc_hd__sdfxbp_1",
        "sky130_fd_sc_hd__sdfxbp_2",
        "sky130_fd_sc_hd__sdfxtp_1",
        "sky130_fd_sc_hd__sdfxtp_2",
        "sky130_fd_sc_hd__sdfxtp_4",
        "sky130_fd_sc_hd__sdlclkp_1",
        "sky130_fd_sc_hd__sdlclkp_2",
        "sky130_fd_sc_hd__sdlclkp_4",
        "sky130_fd_sc_hd__sedfxbp_1",
        "sky130_fd_sc_hd__sedfxbp_2",
        "sky130_fd_sc_hd__sedfxtp_1",
        "sky130_fd_sc_hd__sedfxtp_2",
        "sky130_fd_sc_hd__sedfxtp_4",
        "sky130_fd_sc_hd__tap_1",
        "sky130_fd_sc_hd__tap_2",
        "sky130_fd_sc_hd__tapvgnd2_1",
        "sky130_fd_sc_hd__tapvgnd_1",
        "sky130_fd_sc_hd__tapvpwrvgnd_1",
        "sky130_fd_sc_hd__xnor2_1",
        "sky130_fd_sc_hd__xnor2_2",
        "sky130_fd_sc_hd__xnor2_4",
        "sky130_fd_sc_hd__xnor3_1",
        "sky130_fd_sc_hd__xnor3_2",
        "sky130_fd_sc_hd__xnor3_4",
        "sky130_fd_sc_hd__xor2_1",
        "sky130_fd_sc_hd__xor2_2",
        "sky130_fd_sc_hd__xor2_4",
        "sky130_fd_sc_hd__xor3_1",
        "sky130_fd_sc_hd__xor3_2",
        "sky130_fd_sc_hd__xor3_4",
    ], "cells not extracted successfully"


def test_gf_basic():
    from lef_parser import parse_files

    lef = parse_files(
        [
            os.path.join(pytest.test_root, "files", "gf.tlef"),
            os.path.join(pytest.test_root, "files", "gf.lef"),
        ]
    )
    assert list(lef.layers.keys()) == [
        "Pwell",
        "Nwell",
        "Poly2",
        "CON",
        "Metal1",
        "Via1",
        "Metal2",
        "Via2",
        "Metal3",
        "Via3",
        "Metal4",
        "Via4",
        "Metal5",
        "OVERLAP",
        "PR_bndry",
    ], "layers not extracted successfully"
    assert list(lef.macros.keys()) == [
        "gf180mcu_fd_sc_mcu7t5v0__addf_1",
        "gf180mcu_fd_sc_mcu7t5v0__addf_2",
        "gf180mcu_fd_sc_mcu7t5v0__addf_4",
        "gf180mcu_fd_sc_mcu7t5v0__addh_1",
        "gf180mcu_fd_sc_mcu7t5v0__addh_2",
        "gf180mcu_fd_sc_mcu7t5v0__addh_4",
        "gf180mcu_fd_sc_mcu7t5v0__and2_1",
        "gf180mcu_fd_sc_mcu7t5v0__and2_2",
        "gf180mcu_fd_sc_mcu7t5v0__and2_4",
        "gf180mcu_fd_sc_mcu7t5v0__and3_1",
        "gf180mcu_fd_sc_mcu7t5v0__and3_2",
        "gf180mcu_fd_sc_mcu7t5v0__and3_4",
        "gf180mcu_fd_sc_mcu7t5v0__and4_1",
        "gf180mcu_fd_sc_mcu7t5v0__and4_2",
        "gf180mcu_fd_sc_mcu7t5v0__and4_4",
        "gf180mcu_fd_sc_mcu7t5v0__antenna",
        "gf180mcu_fd_sc_mcu7t5v0__aoi21_1",
        "gf180mcu_fd_sc_mcu7t5v0__aoi21_2",
        "gf180mcu_fd_sc_mcu7t5v0__aoi21_4",
        "gf180mcu_fd_sc_mcu7t5v0__aoi22_1",
        "gf180mcu_fd_sc_mcu7t5v0__aoi22_2",
        "gf180mcu_fd_sc_mcu7t5v0__aoi22_4",
        "gf180mcu_fd_sc_mcu7t5v0__aoi211_1",
        "gf180mcu_fd_sc_mcu7t5v0__aoi211_2",
        "gf180mcu_fd_sc_mcu7t5v0__aoi211_4",
        "gf180mcu_fd_sc_mcu7t5v0__aoi221_1",
        "gf180mcu_fd_sc_mcu7t5v0__aoi221_2",
        "gf180mcu_fd_sc_mcu7t5v0__aoi221_4",
        "gf180mcu_fd_sc_mcu7t5v0__aoi222_1",
        "gf180mcu_fd_sc_mcu7t5v0__aoi222_2",
        "gf180mcu_fd_sc_mcu7t5v0__aoi222_4",
        "gf180mcu_fd_sc_mcu7t5v0__buf_1",
        "gf180mcu_fd_sc_mcu7t5v0__buf_2",
        "gf180mcu_fd_sc_mcu7t5v0__buf_3",
        "gf180mcu_fd_sc_mcu7t5v0__buf_4",
        "gf180mcu_fd_sc_mcu7t5v0__buf_8",
        "gf180mcu_fd_sc_mcu7t5v0__buf_12",
        "gf180mcu_fd_sc_mcu7t5v0__buf_16",
        "gf180mcu_fd_sc_mcu7t5v0__buf_20",
        "gf180mcu_fd_sc_mcu7t5v0__bufz_1",
        "gf180mcu_fd_sc_mcu7t5v0__bufz_2",
        "gf180mcu_fd_sc_mcu7t5v0__bufz_3",
        "gf180mcu_fd_sc_mcu7t5v0__bufz_4",
        "gf180mcu_fd_sc_mcu7t5v0__bufz_8",
        "gf180mcu_fd_sc_mcu7t5v0__bufz_12",
        "gf180mcu_fd_sc_mcu7t5v0__bufz_16",
        "gf180mcu_fd_sc_mcu7t5v0__clkbuf_1",
        "gf180mcu_fd_sc_mcu7t5v0__clkbuf_2",
        "gf180mcu_fd_sc_mcu7t5v0__clkbuf_3",
        "gf180mcu_fd_sc_mcu7t5v0__clkbuf_4",
        "gf180mcu_fd_sc_mcu7t5v0__clkbuf_8",
        "gf180mcu_fd_sc_mcu7t5v0__clkbuf_12",
        "gf180mcu_fd_sc_mcu7t5v0__clkbuf_16",
        "gf180mcu_fd_sc_mcu7t5v0__clkbuf_20",
        "gf180mcu_fd_sc_mcu7t5v0__clkinv_1",
        "gf180mcu_fd_sc_mcu7t5v0__clkinv_2",
        "gf180mcu_fd_sc_mcu7t5v0__clkinv_3",
        "gf180mcu_fd_sc_mcu7t5v0__clkinv_4",
        "gf180mcu_fd_sc_mcu7t5v0__clkinv_8",
        "gf180mcu_fd_sc_mcu7t5v0__clkinv_12",
        "gf180mcu_fd_sc_mcu7t5v0__clkinv_16",
        "gf180mcu_fd_sc_mcu7t5v0__clkinv_20",
        "gf180mcu_fd_sc_mcu7t5v0__dffnq_1",
        "gf180mcu_fd_sc_mcu7t5v0__dffnq_2",
        "gf180mcu_fd_sc_mcu7t5v0__dffnq_4",
        "gf180mcu_fd_sc_mcu7t5v0__dffnrnq_1",
        "gf180mcu_fd_sc_mcu7t5v0__dffnrnq_2",
        "gf180mcu_fd_sc_mcu7t5v0__dffnrnq_4",
        "gf180mcu_fd_sc_mcu7t5v0__dffnrsnq_1",
        "gf180mcu_fd_sc_mcu7t5v0__dffnrsnq_2",
        "gf180mcu_fd_sc_mcu7t5v0__dffnrsnq_4",
        "gf180mcu_fd_sc_mcu7t5v0__dffnsnq_1",
        "gf180mcu_fd_sc_mcu7t5v0__dffnsnq_2",
        "gf180mcu_fd_sc_mcu7t5v0__dffnsnq_4",
        "gf180mcu_fd_sc_mcu7t5v0__dffq_1",
        "gf180mcu_fd_sc_mcu7t5v0__dffq_2",
        "gf180mcu_fd_sc_mcu7t5v0__dffq_4",
        "gf180mcu_fd_sc_mcu7t5v0__dffrnq_1",
        "gf180mcu_fd_sc_mcu7t5v0__dffrnq_2",
        "gf180mcu_fd_sc_mcu7t5v0__dffrnq_4",
        "gf180mcu_fd_sc_mcu7t5v0__dffrsnq_1",
        "gf180mcu_fd_sc_mcu7t5v0__dffrsnq_2",
        "gf180mcu_fd_sc_mcu7t5v0__dffrsnq_4",
        "gf180mcu_fd_sc_mcu7t5v0__dffsnq_1",
        "gf180mcu_fd_sc_mcu7t5v0__dffsnq_2",
        "gf180mcu_fd_sc_mcu7t5v0__dffsnq_4",
        "gf180mcu_fd_sc_mcu7t5v0__dlya_1",
        "gf180mcu_fd_sc_mcu7t5v0__dlya_2",
        "gf180mcu_fd_sc_mcu7t5v0__dlya_4",
        "gf180mcu_fd_sc_mcu7t5v0__dlyb_1",
        "gf180mcu_fd_sc_mcu7t5v0__dlyb_2",
        "gf180mcu_fd_sc_mcu7t5v0__dlyb_4",
        "gf180mcu_fd_sc_mcu7t5v0__dlyc_1",
        "gf180mcu_fd_sc_mcu7t5v0__dlyc_2",
        "gf180mcu_fd_sc_mcu7t5v0__dlyc_4",
        "gf180mcu_fd_sc_mcu7t5v0__dlyd_1",
        "gf180mcu_fd_sc_mcu7t5v0__dlyd_2",
        "gf180mcu_fd_sc_mcu7t5v0__dlyd_4",
        "gf180mcu_fd_sc_mcu7t5v0__endcap",
        "gf180mcu_fd_sc_mcu7t5v0__fill_1",
        "gf180mcu_fd_sc_mcu7t5v0__fill_2",
        "gf180mcu_fd_sc_mcu7t5v0__fill_4",
        "gf180mcu_fd_sc_mcu7t5v0__fill_8",
        "gf180mcu_fd_sc_mcu7t5v0__fill_16",
        "gf180mcu_fd_sc_mcu7t5v0__fill_32",
        "gf180mcu_fd_sc_mcu7t5v0__fill_64",
        "gf180mcu_fd_sc_mcu7t5v0__fillcap_4",
        "gf180mcu_fd_sc_mcu7t5v0__fillcap_8",
        "gf180mcu_fd_sc_mcu7t5v0__fillcap_16",
        "gf180mcu_fd_sc_mcu7t5v0__fillcap_32",
        "gf180mcu_fd_sc_mcu7t5v0__fillcap_64",
        "gf180mcu_fd_sc_mcu7t5v0__filltie",
        "gf180mcu_fd_sc_mcu7t5v0__hold",
        "gf180mcu_fd_sc_mcu7t5v0__icgtn_1",
        "gf180mcu_fd_sc_mcu7t5v0__icgtn_2",
        "gf180mcu_fd_sc_mcu7t5v0__icgtn_4",
        "gf180mcu_fd_sc_mcu7t5v0__icgtp_1",
        "gf180mcu_fd_sc_mcu7t5v0__icgtp_2",
        "gf180mcu_fd_sc_mcu7t5v0__icgtp_4",
        "gf180mcu_fd_sc_mcu7t5v0__inv_1",
        "gf180mcu_fd_sc_mcu7t5v0__inv_2",
        "gf180mcu_fd_sc_mcu7t5v0__inv_3",
        "gf180mcu_fd_sc_mcu7t5v0__inv_4",
        "gf180mcu_fd_sc_mcu7t5v0__inv_8",
        "gf180mcu_fd_sc_mcu7t5v0__inv_12",
        "gf180mcu_fd_sc_mcu7t5v0__inv_16",
        "gf180mcu_fd_sc_mcu7t5v0__inv_20",
        "gf180mcu_fd_sc_mcu7t5v0__invz_1",
        "gf180mcu_fd_sc_mcu7t5v0__invz_2",
        "gf180mcu_fd_sc_mcu7t5v0__invz_3",
        "gf180mcu_fd_sc_mcu7t5v0__invz_4",
        "gf180mcu_fd_sc_mcu7t5v0__invz_8",
        "gf180mcu_fd_sc_mcu7t5v0__invz_12",
        "gf180mcu_fd_sc_mcu7t5v0__invz_16",
        "gf180mcu_fd_sc_mcu7t5v0__latq_1",
        "gf180mcu_fd_sc_mcu7t5v0__latq_2",
        "gf180mcu_fd_sc_mcu7t5v0__latq_4",
        "gf180mcu_fd_sc_mcu7t5v0__latrnq_1",
        "gf180mcu_fd_sc_mcu7t5v0__latrnq_2",
        "gf180mcu_fd_sc_mcu7t5v0__latrnq_4",
        "gf180mcu_fd_sc_mcu7t5v0__latrsnq_1",
        "gf180mcu_fd_sc_mcu7t5v0__latrsnq_2",
        "gf180mcu_fd_sc_mcu7t5v0__latrsnq_4",
        "gf180mcu_fd_sc_mcu7t5v0__latsnq_1",
        "gf180mcu_fd_sc_mcu7t5v0__latsnq_2",
        "gf180mcu_fd_sc_mcu7t5v0__latsnq_4",
        "gf180mcu_fd_sc_mcu7t5v0__mux2_1",
        "gf180mcu_fd_sc_mcu7t5v0__mux2_2",
        "gf180mcu_fd_sc_mcu7t5v0__mux2_4",
        "gf180mcu_fd_sc_mcu7t5v0__mux4_1",
        "gf180mcu_fd_sc_mcu7t5v0__mux4_2",
        "gf180mcu_fd_sc_mcu7t5v0__mux4_4",
        "gf180mcu_fd_sc_mcu7t5v0__nand2_1",
        "gf180mcu_fd_sc_mcu7t5v0__nand2_2",
        "gf180mcu_fd_sc_mcu7t5v0__nand2_4",
        "gf180mcu_fd_sc_mcu7t5v0__nand3_1",
        "gf180mcu_fd_sc_mcu7t5v0__nand3_2",
        "gf180mcu_fd_sc_mcu7t5v0__nand3_4",
        "gf180mcu_fd_sc_mcu7t5v0__nand4_1",
        "gf180mcu_fd_sc_mcu7t5v0__nand4_2",
        "gf180mcu_fd_sc_mcu7t5v0__nand4_4",
        "gf180mcu_fd_sc_mcu7t5v0__nor2_1",
        "gf180mcu_fd_sc_mcu7t5v0__nor2_2",
        "gf180mcu_fd_sc_mcu7t5v0__nor2_4",
        "gf180mcu_fd_sc_mcu7t5v0__nor3_1",
        "gf180mcu_fd_sc_mcu7t5v0__nor3_2",
        "gf180mcu_fd_sc_mcu7t5v0__nor3_4",
        "gf180mcu_fd_sc_mcu7t5v0__nor4_1",
        "gf180mcu_fd_sc_mcu7t5v0__nor4_2",
        "gf180mcu_fd_sc_mcu7t5v0__nor4_4",
        "gf180mcu_fd_sc_mcu7t5v0__oai21_1",
        "gf180mcu_fd_sc_mcu7t5v0__oai21_2",
        "gf180mcu_fd_sc_mcu7t5v0__oai21_4",
        "gf180mcu_fd_sc_mcu7t5v0__oai22_1",
        "gf180mcu_fd_sc_mcu7t5v0__oai22_2",
        "gf180mcu_fd_sc_mcu7t5v0__oai22_4",
        "gf180mcu_fd_sc_mcu7t5v0__oai31_1",
        "gf180mcu_fd_sc_mcu7t5v0__oai31_2",
        "gf180mcu_fd_sc_mcu7t5v0__oai31_4",
        "gf180mcu_fd_sc_mcu7t5v0__oai32_1",
        "gf180mcu_fd_sc_mcu7t5v0__oai32_2",
        "gf180mcu_fd_sc_mcu7t5v0__oai32_4",
        "gf180mcu_fd_sc_mcu7t5v0__oai33_1",
        "gf180mcu_fd_sc_mcu7t5v0__oai33_2",
        "gf180mcu_fd_sc_mcu7t5v0__oai33_4",
        "gf180mcu_fd_sc_mcu7t5v0__oai211_1",
        "gf180mcu_fd_sc_mcu7t5v0__oai211_2",
        "gf180mcu_fd_sc_mcu7t5v0__oai211_4",
        "gf180mcu_fd_sc_mcu7t5v0__oai221_1",
        "gf180mcu_fd_sc_mcu7t5v0__oai221_2",
        "gf180mcu_fd_sc_mcu7t5v0__oai221_4",
        "gf180mcu_fd_sc_mcu7t5v0__oai222_1",
        "gf180mcu_fd_sc_mcu7t5v0__oai222_2",
        "gf180mcu_fd_sc_mcu7t5v0__oai222_4",
        "gf180mcu_fd_sc_mcu7t5v0__or2_1",
        "gf180mcu_fd_sc_mcu7t5v0__or2_2",
        "gf180mcu_fd_sc_mcu7t5v0__or2_4",
        "gf180mcu_fd_sc_mcu7t5v0__or3_1",
        "gf180mcu_fd_sc_mcu7t5v0__or3_2",
        "gf180mcu_fd_sc_mcu7t5v0__or3_4",
        "gf180mcu_fd_sc_mcu7t5v0__or4_1",
        "gf180mcu_fd_sc_mcu7t5v0__or4_2",
        "gf180mcu_fd_sc_mcu7t5v0__or4_4",
        "gf180mcu_fd_sc_mcu7t5v0__sdffq_1",
        "gf180mcu_fd_sc_mcu7t5v0__sdffq_2",
        "gf180mcu_fd_sc_mcu7t5v0__sdffq_4",
        "gf180mcu_fd_sc_mcu7t5v0__sdffrnq_1",
        "gf180mcu_fd_sc_mcu7t5v0__sdffrnq_2",
        "gf180mcu_fd_sc_mcu7t5v0__sdffrnq_4",
        "gf180mcu_fd_sc_mcu7t5v0__sdffrsnq_1",
        "gf180mcu_fd_sc_mcu7t5v0__sdffrsnq_2",
        "gf180mcu_fd_sc_mcu7t5v0__sdffrsnq_4",
        "gf180mcu_fd_sc_mcu7t5v0__sdffsnq_1",
        "gf180mcu_fd_sc_mcu7t5v0__sdffsnq_2",
        "gf180mcu_fd_sc_mcu7t5v0__sdffsnq_4",
        "gf180mcu_fd_sc_mcu7t5v0__tieh",
        "gf180mcu_fd_sc_mcu7t5v0__tiel",
        "gf180mcu_fd_sc_mcu7t5v0__xnor2_1",
        "gf180mcu_fd_sc_mcu7t5v0__xnor2_2",
        "gf180mcu_fd_sc_mcu7t5v0__xnor2_4",
        "gf180mcu_fd_sc_mcu7t5v0__xnor3_1",
        "gf180mcu_fd_sc_mcu7t5v0__xnor3_2",
        "gf180mcu_fd_sc_mcu7t5v0__xnor3_4",
        "gf180mcu_fd_sc_mcu7t5v0__xor2_1",
        "gf180mcu_fd_sc_mcu7t5v0__xor2_2",
        "gf180mcu_fd_sc_mcu7t5v0__xor2_4",
        "gf180mcu_fd_sc_mcu7t5v0__xor3_1",
        "gf180mcu_fd_sc_mcu7t5v0__xor3_2",
        "gf180mcu_fd_sc_mcu7t5v0__xor3_4",
    ], "cells not extracted successfully"
